// src/renderers/InfluenceConditionsRenderer.js
import { DSIUnit } from "dsiunits-js";

export class InfluenceConditionsRenderer {
    constructor(influenceConditionsData, language) {
        this.data = influenceConditionsData;
        this.language = language;
    }

    render() {
        const container = document.createElement('div');
        container.innerHTML = `<h3>Influence Conditions</h3>`;
        let conditions = this.data['dcc:influenceCondition'];
        if (!conditions) {
            container.textContent = 'No influence conditions available.';
            return container;
        }
        if (!Array.isArray(conditions)) {
            conditions = [conditions];
        }
        conditions.forEach(condition => {
            // Create a collapsible section for each influence condition
            const details = document.createElement('details');
            details.style.border = '1px solid #ccc';
            details.style.padding = '8px';
            details.style.marginBottom = '10px';

            // Summary: always visible, shows the condition name and, if only one quantity exists, its value (plain text)
            const summary = document.createElement('summary');
            const condName = this._getText(condition['dcc:name']);
            let summaryText = condName;
            const quantities = this._getQuantities(condition);
            if (quantities.length === 1) {
                // Use plain flag for summary display so that HTML is not double-escaped
                const qty = quantities[0];
                const valueStr = this._formatQuantity(qty, true);
                summaryText += ` : ${valueStr}`;
            }
            // Use innerHTML so that HTML markup in the unit is rendered
            summary.innerHTML = summaryText;
            details.appendChild(summary);

            // Expanded content: condition description and quantities table
            const contentDiv = document.createElement('div');
            contentDiv.style.marginTop = '8px';
            contentDiv.style.fontFamily = 'sans-serif';
            const descText = this._getText(condition['dcc:description']);
            if (descText) {
                const p = document.createElement('p');
                p.textContent = descText;
                contentDiv.appendChild(p);
            }
            // Render quantities table if available
            if (condition['dcc:data'] && condition['dcc:data']['dcc:quantity']) {
                let quantities = this._getQuantities(condition);
                const table = document.createElement('table');
                table.style.width = '100%';
                table.style.borderCollapse = 'collapse';

                // Header row for the table (removed "Additional Info" column)
                const headerRow = document.createElement('tr');
                ['Quantity', 'Value', 'Description'].forEach(text => {
                    const th = document.createElement('th');
                    th.textContent = text;
                    th.style.border = '1px solid #ccc';
                    th.style.padding = '4px';
                    headerRow.appendChild(th);
                });
                table.appendChild(headerRow);

                // Render each quantity as a row
                quantities.forEach(q => {
                    const row = document.createElement('tr');

                    // Column 1: Quantity name
                    const nameCell = document.createElement('td');
                    nameCell.style.border = '1px solid #ccc';
                    nameCell.style.padding = '4px';
                    nameCell.textContent = this._getText(q['dcc:name']);
                    row.appendChild(nameCell);

                    // Column 2: Value (with unit, uncertainty, merged) – rendered with HTML markup
                    const valueCell = document.createElement('td');
                    valueCell.style.border = '1px solid #ccc';
                    valueCell.style.padding = '4px';
                    const formattedValue = this._formatQuantity(q, false);
                    valueCell.innerHTML = formattedValue;
                    // Attach tooltip for additional data if present
                    const additional = this._getAdditionalData(q);
                    if (Object.keys(additional).length > 0) {
                        const infoSpan = document.createElement('span');
                        infoSpan.textContent = ' ⓘ';
                        infoSpan.style.cursor = 'pointer';
                        infoSpan.style.color = '#888';
                        infoSpan.title = JSON.stringify(additional, null, 2);
                        valueCell.appendChild(infoSpan);
                    }
                    row.appendChild(valueCell);

                    // Column 3: Description for the quantity
                    const descCell = document.createElement('td');
                    descCell.style.border = '1px solid #ccc';
                    descCell.style.padding = '4px';
                    descCell.textContent = this._getText(q['dcc:description']);
                    row.appendChild(descCell);

                    table.appendChild(row);
                });
                contentDiv.appendChild(table);
            }
            details.appendChild(contentDiv);
            container.appendChild(details);
        });
        return container;
    }

    // Helper: return language-specific text from a node
    _getText(node) {
        if (!node) return '';
        const content = node['dcc:content'];
        if (Array.isArray(content)) {
            const match = content.find(item => item.$ && item.$.lang === this.language) || content[0];
            return match._ || match;
        }
        return content._ || content;
    }

    // Helper: extract quantities array from an influence condition
    _getQuantities(condition) {
        let quantities = [];
        if (condition['dcc:data'] && condition['dcc:data']['dcc:quantity']) {
            quantities = Array.isArray(condition['dcc:data']['dcc:quantity'])
                ? condition['dcc:data']['dcc:quantity']
                : [condition['dcc:data']['dcc:quantity']];
        }
        return quantities;
    }

    /**
     * Helper: Format a quantity's value.
     * @param {Object} quantity - The quantity node.
     * @param {boolean} plain - If true, render unit as plain text; otherwise use HTML from DSIUnit.
     * @returns {string}
     */
    _formatQuantity(quantity, plain = false) {
        // Handle noQuantity (categorical data)
        if (quantity['dcc:noQuantity']) {
            return this._getText(quantity['dcc:noQuantity']);
        }
        // Handle si:hybrid block: map over si:real elements.
        if (quantity['si:hybrid']) {
            const hybrid = quantity['si:hybrid'];
            let reals = hybrid['si:real'];
            if (!Array.isArray(reals)) {
                reals = [reals];
            }
            const formatted = reals.map((real, index) => {
                const value = real['si:value'] ? real['si:value'].trim() : '';
                let unit = '';
                if (real['si:unit']) {
                    const rawUnit = real['si:unit'].trim();
                    const unitObj = new DSIUnit(rawUnit);
                    unit = plain ? unitObj.toHTML() : unitObj.toHTML({ oneLine: true });
                }
                let uncertainty = '';
                if (real['si:measurementUncertaintyUnivariate'] &&
                    real['si:measurementUncertaintyUnivariate']['si:expandedMU'] &&
                    real['si:measurementUncertaintyUnivariate']['si:expandedMU']['si:valueExpandedMU']) {
                    uncertainty = real['si:measurementUncertaintyUnivariate']['si:expandedMU']['si:valueExpandedMU'].trim();
                }
                let result = uncertainty
                    ? `${value} ± ${uncertainty} ${unit}`
                    : `${value} ${unit}`;
                if (index > 0) {
                    // For subsequent representations, wrap in a light gray span.
                    result = `<span style="color:lightgray;">(${result})</span>`;
                }
                return result;
            });
            return formatted.join(' ');
        }
        // Handle si:realListXMLList
        if (quantity['si:realListXMLList']) {
            const rl = quantity['si:realListXMLList'];
            const values = rl['si:valueXMLList'] ? rl['si:valueXMLList'].trim().split(/\s+/) : [];
            let unit = '';
            if (rl['si:unitXMLList']) {
                const rawUnit = rl['si:unitXMLList'].trim();
                const unitObj = new DSIUnit(rawUnit);
                unit = plain ? unitObj.toHTML() : unitObj.toHTML({ oneLine: true });
            }
            let uncertainty = [];
            if (rl['si:measurementUncertaintyUnivariateXMLList'] &&
                rl['si:measurementUncertaintyUnivariateXMLList']['si:expandedMUXMLList'] &&
                rl['si:measurementUncertaintyUnivariateXMLList']['si:expandedMUXMLList']['si:valueExpandedMUXMLList']) {
                uncertainty = rl['si:measurementUncertaintyUnivariateXMLList']['si:expandedMUXMLList']['si:valueExpandedMUXMLList']
                    .trim().split(/\s+/);
            }
            const formatted = values.map((val, i) => {
                const unc = (uncertainty[i] !== undefined) ? uncertainty[i] : '';
                return unc ? `${val} ± ${unc} ${unit}` : `${val} ${unit}`;
            });
            return formatted.join(' / ');
        }
        // Handle si:real
        if (quantity['si:real']) {
            const real = quantity['si:real'];
            const value = real['si:value'] ? real['si:value'].trim() : '';
            let unit = '';
            if (real['si:unit']) {
                const rawUnit = real['si:unit'].trim();
                const unitObj = new DSIUnit(rawUnit);
                unit = plain ? unitObj.toHTML() : unitObj.toHTML({ oneLine: true });
            }
            let uncertainty = '';
            if (real['si:measurementUncertaintyUnivariate'] &&
                real['si:measurementUncertaintyUnivariate']['si:expandedMU'] &&
                real['si:measurementUncertaintyUnivariate']['si:expandedMU']['si:valueExpandedMU']) {
                uncertainty = real['si:measurementUncertaintyUnivariate']['si:expandedMU']['si:valueExpandedMU'].trim();
            }
            return uncertainty ? `${value} ± ${uncertainty} ${unit}` : `${value} ${unit}`;
        }
        return '';
    }

    // Helper: extract additional data (all keys except the common ones) for tooltip purposes
    _getAdditionalData(quantity) {
        const exclude = ['dcc:name', 'dcc:description', 'si:real', 'si:realListXMLList', 'dcc:noQuantity'];
        const additional = {};
        Object.keys(quantity).forEach(key => {
            if (!exclude.includes(key)) {
                additional[key] = quantity[key];
            }
        });
        return additional;
    }
}
